@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: Utility.py 10447 2017-11-06 23:27:59Z David $
+# $Id: Utility.py 10797 2018-03-01 02:31:02Z David $
 #
 # Copyright (c) 2012 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: David $
-# $Date: 2017-11-07 07:27:59 +0800 (Tue, 07 Nov 2017) $
-# $Revision: 10447 $
+# $Date: 2018-03-01 10:31:02 +0800 (Thu, 01 Mar 2018) $
+# $Revision: 10797 $
 
 import sys
 import traceback
@@ -28,7 +28,7 @@ from unidecode import unidecode
 
 from Iuppiter.Encoding import _unicode
 
-from Theophrastus.models import Link
+from emencia.django.newsletter.models import Link
 
 def trackLinks(content, context):
     """
