@@ -15,12 +15,21 @@
 # $Date: 2016-03-14 15:45:28 +0800 (一, 14  3 2016) $
 # $Revision: 9589 $
 
+from django.conf import settings
 from django.conf.urls import url, include, patterns
 
 #import views
 
-urlpatterns = patterns('',
-    # Integration.
-    url(r'', include('Theophrastus.integration.urls.api')),
-    url(r'', include('Theophrastus.newsletter_extension.urls.api')),
-)
+urlpatterns = patterns('', )
+
+# Newsletter_extension api
+if 'Theophrastus.newsletter_extension' in settings.INSTALLED_APPS:
+    urlpatterns += (
+        url(r'', include('Theophrastus.newsletter_extension.urls.api')),
+    )
+
+# Integration api
+if 'Theophrastus.integration' in settings.INSTALLED_APPS:
+    urlpatterns += (
+        url(r'', include('Theophrastus.integration.urls.api')),
+    )
