@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: Mailer.py 10797 2018-03-01 02:31:02Z David $
+# $Id: Mailer.py 10850 2018-03-17 23:41:09Z David $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -13,7 +13,7 @@
 #
 # $Author: David $ (Last)
 # $Date: 2013-01-30 12:13:45 +0800$
-# $Revision: 10797 $
+# $Revision: 10850 $
 
 import os
 import random
@@ -27,7 +27,7 @@ from smtplib import SMTPRecipientsRefused
 from django.core.mail import EmailMessage
 from django.utils.encoding import smart_str, smart_unicode
 from django.contrib.sites.models import Site
-from django.template import Context, Template
+from django.template import Context
 from django.template.loader import render_to_string
 from django.conf import settings
 from django.core.urlresolvers import reverse
@@ -48,9 +48,11 @@ from Iuno.cloud.mail import SendMessageException, RetryAndSendException
 
 from emencia.django.newsletter.models import ContactMailingStatus, Newsletter
 
-from Theophrastus.newsletter_extension.models import Header, Footer, ErrorMessage
+from Theophrastus.cloud.models import ErrorMessage
 from Theophrastus.cloud.service import CloudService
 from Theophrastus.Utility import getComment, trackLinks
+from Theophrastus.newsletter_extension.views import getHeaderContent, \
+                                                    getFooterContent
 
 cloudSrv = CloudService.getInstance()
 
@@ -235,61 +237,6 @@ class CloudMailer(Mailer):
             s = '%s end.' % _s
             self.logger.info('[%d]_TEST_END: %s' % (newsletterId, s))
 
-    def _replaceContent(self, content):
-        """
-        Replace content.
-
-        @param content The content of replaced.
-        """
-
-        if (hasattr(settings, 'SECURE_PROXY_SSL_HEADER') and
-            settings.SECURE_PROXY_SSL_HEADER):
-            protocol = 'https'
-        else:
-            protocol = 'http'
-
-        mapping = (
-            ("http://NEWSLETTER_SITE_LINK",
-             ("%s://{{ domain }}{%% url 'newsletter_newsletter_contact' " % (
-                 protocol, ) +
-             "slug=newsletter.slug uidb36=uidb36 token=token %}")),
-            ("http://NEWSLETTER_UNSUBSCRIBE_LINK",
-             ("{%% if uidb36 and token %%}%s://{{ domain }}" % (protocol, ) +
-             "{% url 'newsletter_mailinglist_unsubscribe' "
-             "slug=newsletter.slug uidb36=uidb36 token=token %}"
-             "{% else %}#{% endif %}")),
-        )
-
-        for (key, _c) in mapping:
-            content = content.replace(key, _c)
-        return content
-
-    def getHeaderContent(self):
-        """
-        Get content of newsletter's header.
-        """
-        try:
-            header = self.newsletter.header
-            if not header:
-                header = Header.objects.all()[0]
-            _content = self._replaceContent(header.content)
-            return Template(_content)
-        except:
-            return None
-
-    def getFooterContent(self):
-        """
-        Get content of newsletter's footer.
-        """
-        try:
-            footer = self.newsletter.footer
-            if not footer:
-                footer = Footer.objects.all()[0]
-            _content = self._replaceContent(footer.content)
-            return Template(_content)
-        except:
-            return None
-
     def buildEmailContent(self, contact):
         """
         Generate the mail content for a contact.
@@ -306,7 +253,7 @@ class CloudMailer(Mailer):
         if TRACKING_LINKS:
             content = trackLinks(content, context)
 
-        headerContent = self.getHeaderContent()
+        headerContent = getHeaderContent(self.newsletter)
         if headerContent is None:
             linkSite = render_to_string(
                 'newsletter/newsletter_link_site.html', context)
@@ -315,7 +262,7 @@ class CloudMailer(Mailer):
         content = body_insertion(content, linkSite)
 
         if INCLUDE_UNSUBSCRIPTION:
-            footerContent = self.getFooterContent()
+            footerContent = getFooterContent(self.newsletter)
             if footerContent is None:
                 unsubscription = render_to_string(
                     'newsletter/newsletter_link_unsubscribe.html', context)
@@ -327,6 +274,7 @@ class CloudMailer(Mailer):
             image_tracking = render_to_string(
                 'newsletter/newsletter_image_tracking.html', context)
             content = body_insertion(content, image_tracking, end=True)
+        
         return smart_unicode(content)
 
     def send(self, contact):
