@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: admin.py 10749 2018-01-29 16:27:24Z David $
+# $Id: admin.py 10797 2018-03-01 02:31:02Z David $
 #
 # Copyright (c) 2013 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,15 +12,16 @@
 # limitations under the License.
 #
 # $Author: David $
-# $Date: 2018-01-30 00:27:24 +0800 (Tue, 30 Jan 2018) $
-# $Revision: 10749 $
+# $Date: 2018-03-01 10:31:02 +0800 (Thu, 01 Mar 2018) $
+# $Revision: 10797 $
 
 from django.contrib import admin
 from django.contrib.admin.views.main import ChangeList
 from django.core.urlresolvers import reverse
 from django.utils.translation import ugettext as _
 
-from Theophrastus.models import Newsletter
+from emencia.django.newsletter.models import Newsletter
+
 from Theophrastus.statistics.admin import NewsletterStatisticsAdmin
 from Theophrastus.integration.service import IntegrationService
 from Theophrastus.integration.forms import AppAdminForm, GroupMappingTableForm
@@ -261,7 +262,7 @@ class GroupMappingTableAdmin(admin.ModelAdmin):
 
 admin.site.register(GroupMappingTable, GroupMappingTableAdmin)
 
-from Theophrastus.models import MailingList
+from emencia.django.newsletter.models import MailingList
 from emencia.django.newsletter.admin import MailingListAdmin
 
 class MailingListChangeList(ChangeList):
@@ -390,6 +391,7 @@ class NewsletterIntegrationChangeList(ChangeList):
         return self.getQuerySet(request=request, original=False)
 
 class NewsletterIntegrationAdmin(NewsletterStatisticsAdmin):
+    
     list_filter = (
         'status', 'sending_date', 'creation_date', 'modification_date',
         AppNewsletterFilter,)
