@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: models.py 10694 2017-12-29 09:22:09Z David $
+# $Id: models.py 10797 2018-03-01 02:31:02Z David $
 #
 # Copyright (c) 2013 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: David $
-# $Date: 2017-12-29 17:22:09 +0800 (Fri, 29 Dec 2017) $
-# $Revision: 10694 $
+# $Date: 2018-03-01 10:31:02 +0800 (Thu, 01 Mar 2018) $
+# $Revision: 10797 $
 
 from django.db import models
 from django.contrib.auth.models import User
@@ -21,8 +21,7 @@ from django.utils.translation import ugettext as _
 
 from Iuppiter.Model import BaseModelMixin
 
-from Theophrastus.models import Newsletter
-
+from emencia.django.newsletter.models import Newsletter
 
 class Group(models.Model, BaseModelMixin):
     name = models.CharField(_('name'), max_length=255)
