@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: views.py 10769 2018-02-06 08:59:35Z David $
+# $Id: views.py 10797 2018-03-01 02:31:02Z David $
 #
 # Copyright (c) 2013 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: David $
-# $Date: 2018-02-06 16:59:35 +0800 (Tue, 06 Feb 2018) $
-# $Revision: 10769 $
+# $Date: 2018-03-01 10:31:02 +0800 (Thu, 01 Mar 2018) $
+# $Revision: 10797 $
 
 import base64
 from datetime import datetime
@@ -36,12 +36,13 @@ from Iuppiter.extension.views import jsonpCallback, view
 from Iuppiter.Encoding import _unicode
 from Iuppiter.Logging import createDebugLogger
 
+from emencia.django.newsletter.models import ContactMailingStatus
+from emencia.django.newsletter.models import Newsletter
+
 from Theophrastus.integration.service import IntegrationService
 from Theophrastus.statistics.StatisticsHandler import getStatisticsTotalData
 from Theophrastus.statistics.StatisticsHandler import getStatisticsTotalRateData
 from Theophrastus.statistics.StatisticsHandler import getSubscriberHistory
-from Theophrastus.models import ContactMailingStatus
-from Theophrastus.models import Newsletter
 from Theophrastus.cloud.views import filterEmail, doVerifyEmailAddress
 from Theophrastus.cloud.views import doSetNotificationTopic, checkSenderByCache
 from Theophrastus.cloud.views import checkNotificationTopic
