@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: StatisticsHandler.py 10762 2018-02-02 07:47:39Z David $
+# $Id: StatisticsHandler.py 10797 2018-03-01 02:31:02Z David $
 #
 # Copyright (c) 2012 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: David $
-# $Date: 2018-02-02 15:47:39 +0800 (Fri, 02 Feb 2018) $
-# $Revision: 10762 $
+# $Date: 2018-03-01 10:31:02 +0800 (Thu, 01 Mar 2018) $
+# $Revision: 10797 $
 
 from datetime import timedelta, datetime
 
@@ -23,8 +23,8 @@ from django.utils.translation import ugettext_lazy as _
 
 from Iuppiter.Encoding import _unicode
 
-from Theophrastus.models import Newsletter
-from Theophrastus.models import ContactMailingStatus
+from emencia.django.newsletter.models import Newsletter
+from emencia.django.newsletter.models import ContactMailingStatus
 from collections import OrderedDict
 
 _STATUS = [
